@@ -1,12 +1,14 @@
 package Pegex::Forth::Runtime;
 use Pegex::Base;
+use Capture::Tiny ':all';
 
 has stack => [];
+has return_stack => [];
 
 sub call {
     my ($self, $word) = @_;
     my $function = $self->dict->{$word}
-        or die "Undefined word '$word'\n";
+        or die "Undefined word: '$word'\n";
     $function->($self);
 }
 
@@ -30,6 +32,13 @@ has dict => {
     print "$num\n";
 },
 
+'.s' => sub {
+    my ($self) = @_;
+    my $stack = $self->stack;
+    my $size = @$stack;
+    print "<$size>" . join('', map " $_", @$stack) . "\n";
+},
+
 '+' => sub {
     my ($self) = @_;
     my ($a, $b) = $self->pop(2);
